@@ -3,22 +3,24 @@
 /* ######################################################################
 
    Hashes - Simple wrapper around the hash functions
-   
+
    This is just used to make building the methods simpler, this is the
    only interface required..
-   
+
    ##################################################################### */
 									/*}}}*/
 #ifndef APTPKG_HASHES_H
 #define APTPKG_HASHES_H
 
 #include <apt-pkg/macros.h>
-#include <apt-pkg/md5.h>
-#include <apt-pkg/sha1.h>
-#include <apt-pkg/sha2.h>
+
+#ifdef APT_COMPILING_APT
+#include <apt-pkg/tagfile-keys.h>
+#endif
 
 #include <cstring>
 #include <string>
+#include <vector>
 
 
 
@@ -26,7 +28,7 @@ class FileFd;
 
 // helper class that contains hash function name
 // and hash
-class HashString
+class APT_PUBLIC HashString
 {
  protected:
    std::string Type;
@@ -38,7 +40,11 @@ class HashString
 
  public:
    HashString(std::string Type, std::string Hash);
+#if APT_PKG_ABI > 600
+   explicit HashString(std::string_view StringedHashString);  // init from str as "type:hash"
+#else
    explicit HashString(std::string StringedHashString);  // init from str as "type:hash"
+#endif
    HashString();
 
    // get hash type used
@@ -61,9 +67,18 @@ class HashString
 
    // return the list of hashes we support
    static APT_PURE const char** SupportedHashes();
+#ifdef APT_COMPILING_APT
+   struct APT_HIDDEN HashSupportInfo {
+      std::string_view name;
+      pkgTagSection::Key namekey;
+      std::string_view chksumsname;
+      pkgTagSection::Key chksumskey;
+   };
+   APT_HIDDEN static std::vector<HashSupportInfo> SupportedHashesInfo();
+#endif
 };
 
-class HashStringList
+class APT_PUBLIC HashStringList
 {
    public:
    /** find best hash if no specific one is requested
@@ -168,18 +183,9 @@ class HashStringList
 };
 
 class PrivateHashes;
-class Hashes
+class APT_PUBLIC Hashes
 {
    PrivateHashes * const d;
-APT_IGNORE_DEPRECATED_PUSH
-   /* TODO: those will disappear in the future as it is hard to add new ones this way.
-    * Use Add* to build the results and get them via GetHashStringList() instead */
-   MD5Summation MD5 APT_PKG_590("Remove");
-   SHA1Summation SHA1 APT_PKG_590("Remove");
-   SHA256Summation SHA256 APT_PKG_590("Remove");
-   SHA512Summation SHA512 APT_PKG_590("Remove");
-APT_IGNORE_DEPRECATED_POP
-
    public:
    static const int UntilEOF = 0;
 
