@@ -23,19 +23,18 @@
 #include <apt-pkg/fileutl.h>
 #include <apt-pkg/hashes.h>
 #include <apt-pkg/proxy.h>
-#include <apt-pkg/string_view.h>
 #include <apt-pkg/strutl.h>
 
+#include <cerrno>
 #include <chrono>
+#include <csignal>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
 #include <cstring>
 #include <iostream>
 #include <sstream>
 #include <arpa/inet.h>
-#include <errno.h>
-#include <signal.h>
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
 #include <sys/select.h>
 #include <sys/stat.h>
 #include <sys/time.h>
@@ -280,7 +279,7 @@ CircleBuf::~CircleBuf()							/*{{{*/
 // UnwrapHTTPConnect - Does the HTTP CONNECT handshake			/*{{{*/
 // ---------------------------------------------------------------------
 /* Performs a TLS handshake on the socket */
-struct HttpConnectFd : public MethodFd
+struct HttpConnectFd final : public MethodFd
 {
    std::unique_ptr<MethodFd> UnderlyingFd;
    std::string Buffer;
@@ -429,7 +428,9 @@ ResultState HttpServerState::Open()
    Out.Reset();
    Persistent = true;
 
+#ifdef HAVE_GNUTLS
    bool tls = (ServerName.Access == "https" || APT::String::Endswith(ServerName.Access, "+https"));
+#endif
 
    // Determine the proxy setting
    // Used to run AutoDetectProxy(ServerName) here, but we now send a Proxy
@@ -454,6 +455,7 @@ ResultState HttpServerState::Open()
 	   {
 	      char *result = getenv("http_proxy");
 	      Proxy = result ? result : "";
+#ifdef HAVE_GNUTLS
 	      if (tls == true)
 	      {
 		 char *result = getenv("https_proxy");
@@ -462,6 +464,7 @@ ResultState HttpServerState::Open()
 		    Proxy = result;
 		 }
 	      }
+#endif
 	   }
    }
    
@@ -475,8 +478,13 @@ ResultState HttpServerState::Open()
    if (Proxy.empty() == false)
       Owner->AddProxyAuth(Proxy, ServerName);
 
+#ifdef HAVE_GNUTLS
    auto const DefaultService = tls ? "https" : "http";
    auto const DefaultPort = tls ? 443 : 80;
+#else
+   auto const DefaultService = "http";
+   auto const DefaultPort = 80;
+#endif
    if (Proxy.Access == "socks5h")
    {
       auto result = Connect(Proxy.Host, Proxy.Port, "socks", 1080, ServerFd, TimeOut, Owner);
@@ -510,12 +518,15 @@ ResultState HttpServerState::Open()
 	    Port = Proxy.Port;
 	 Host = Proxy.Host;
 
+#ifdef HAVE_GNUTLS
 	 if (Proxy.Access == "https" && Port == 0)
 	    Port = 443;
+#endif
       }
       auto result = Connect(Host, Port, DefaultService, DefaultPort, ServerFd, TimeOut, Owner);
       if (result != ResultState::SUCCESSFUL)
 	 return result;
+#ifdef HAVE_GNUTLS
       if (Host == Proxy.Host && Proxy.Access == "https")
       {
 	 aptConfigWrapperForMethods ProxyConf{std::vector<std::string>{"http", "https"}};
@@ -530,10 +541,13 @@ ResultState HttpServerState::Open()
 	 if (result != ResultState::SUCCESSFUL)
 	    return result;
       }
+#endif
    }
 
+#ifdef HAVE_GNUTLS
    if (tls)
       return UnwrapTLS(ServerName.Host, ServerFd, TimeOut, Owner, Owner);
+#endif
 
    return ResultState::SUCCESSFUL;
 }
@@ -962,12 +976,12 @@ void HttpMethod::SendReq(FetchItem *Itm)
 #ifdef HAVE_SYSTEMD
    if (ConfigFindB("User-Agent-Non-Interactive", false))
    {
-      using APT::operator""_sv;
+      using std::literals::operator""sv;
       char *unit = nullptr;
       sd_pid_get_unit(getpid(), &unit);
       if (unit != nullptr && *unit != '\0' && not APT::String::Startswith(unit, "user@") // user@ _is_ interactive
-	  && "packagekit.service"_sv != unit						 // packagekit likely is interactive
-	  && "dbus.service"_sv != unit)							 // aptdaemon and qapt don't have systemd services
+	  && "packagekit.service"sv != unit						 // packagekit likely is interactive
+	  && "dbus.service"sv != unit)							 // aptdaemon and qapt don't have systemd services
 	 Req << " non-interactive";
 
       free(unit);
